appBskyGraphReferencelistoptout top-level constant

Map<String, dynamic> const appBskyGraphReferencelistoptout

app.bsky.graph.referencelistoptout

Implementation

const appBskyGraphReferencelistoptout = <String, dynamic>{
  "lexicon": 1,
  "id": "app.bsky.graph.referencelistoptout",
  "defs": {
    "main": {
      "type": "record",
      "description":
          "Record requesting that its author be omitted from the public presentation of a reference list. This record is only enforced when the subject list's current purpose is app.bsky.graph.defs#referencelist. AppView indexes at most one record per actor and list pair, and ignores duplicate records.",
      "key": "tid",
      "record": {
        "type": "object",
        "required": ["subject", "createdAt"],
        "properties": {
          "subject": {
            "type": "string",
            "format": "at-uri",
            "description":
                "Canonical, DID-based AT URI of the app.bsky.graph.list record from which the author requests omission.",
          },
          "createdAt": {"type": "string", "format": "datetime"},
        },
      },
    },
  },
};