appBskyVideoDefs top-level constant
app.bsky.video.defs
Implementation
const appBskyVideoDefs = <String, dynamic>{
"lexicon": 1,
"id": "app.bsky.video.defs",
"defs": {
"jobStatus": {
"type": "object",
"required": ["jobId", "did", "state"],
"properties": {
"jobId": {"type": "string"},
"did": {"type": "string", "format": "did"},
"state": {
"type": "string",
"description":
"The state of the video processing job. All values not listed as a known value indicate that the job is in process.",
"knownValues": [
"JOB_STATE_CREATED",
"JOB_STATE_ENCODING",
"JOB_STATE_ENCODED",
"JOB_STATE_SCANNING",
"JOB_STATE_SCANNED",
"JOB_STATE_UPLOADING",
"JOB_STATE_UPLOADED",
"JOB_STATE_COMPLETED",
"JOB_STATE_FAILED",
],
},
"progress": {
"type": "integer",
"description": "Progress within the current processing state.",
"minimum": 0,
"maximum": 100,
},
"blob": {"type": "blob"},
"error": {"type": "string"},
"failureCode": {
"type": "string",
"description":
"A machine-readable code for why the video processing job failed.",
"knownValues": [
"validation_failure",
"encoding_failure",
"pds_upload_failure",
"pds_upload_unsupported_blob_size",
"generic_failure",
],
},
"message": {"type": "string"},
},
},
},
};