chatBskyConvoGetConvoAvailability top-level constant
chat.bsky.convo.getConvoAvailability
Implementation
const chatBskyConvoGetConvoAvailability = <String, dynamic>{
"lexicon": 1,
"id": "chat.bsky.convo.getConvoAvailability",
"defs": {
"main": {
"type": "query",
"description":
"Check whether the requester and the other members can start a 1-1 chat. Only applicable to direct (non-group) conversations. If an existing convo is found for these members, it is returned. Does not create a new convo if it doesn't exist.",
"parameters": {
"type": "params",
"required": ["members"],
"properties": {
"members": {
"type": "array",
"items": {"type": "string", "format": "did"},
"minLength": 1,
"maxLength": 10,
},
},
},
"output": {
"encoding": "application/json",
"schema": {
"type": "object",
"required": ["canChat"],
"properties": {
"canChat": {"type": "boolean"},
"convo": {"type": "ref", "ref": "chat.bsky.convo.defs#convoView"},
},
},
},
},
},
};