siteStandardThemeBasic top-level constant

Map<String, dynamic> const siteStandardThemeBasic

site.standard.theme.basic

Implementation

const siteStandardThemeBasic = <String, dynamic>{
  "lexicon": 1,
  "id": "site.standard.theme.basic",
  "defs": {
    "main": {
      "type": "record",
      "description":
          "A simplified theme definition for publications, providing basic color customization for content display across different platforms and applications.",
      "key": "tid",
      "record": {
        "type": "object",
        "required": ["background", "foreground", "accent", "accentForeground"],
        "properties": {
          "accent": {
            "type": "union",
            "description": "Color used for links and button backgrounds.",
            "refs": ["site.standard.theme.color#rgb"],
          },
          "accentForeground": {
            "type": "union",
            "description": "Color used for button text.",
            "refs": ["site.standard.theme.color#rgb"],
          },
          "background": {
            "type": "union",
            "description": "Color used for content background.",
            "refs": ["site.standard.theme.color#rgb"],
          },
          "foreground": {
            "type": "union",
            "description": "Color used for content text.",
            "refs": ["site.standard.theme.color#rgb"],
          },
        },
      },
    },
  },
};