toolsOzoneInboxListActionedSubjects top-level constant

Map<String, dynamic> const toolsOzoneInboxListActionedSubjects

tools.ozone.inbox.listActionedSubjects

Implementation

const toolsOzoneInboxListActionedSubjects = <String, dynamic>{
  "lexicon": 1,
  "id": "tools.ozone.inbox.listActionedSubjects",
  "defs": {
    "main": {
      "type": "query",
      "description":
          "List subjects belonging to the authenticated account that have moderation actions from this moderation service.",
      "parameters": {
        "type": "params",
        "properties": {
          "did": {
            "type": "string",
            "format": "did",
            "description":
                "Account to preview. Defaults to the authenticated account; another account requires an active moderator, triage, or admin credential.",
          },
          "filter": {
            "type": "string",
            "description":
                "Filter subject activity. pending includes subjects whose latest appeal report is not closed; resolved includes subjects whose latest appeal report is closed. unread includes subjects whose public updatedAt is after the subjects section's seenAt watermark.",
            "default": "all",
            "enum": ["all", "pending", "resolved", "unread"],
          },
          "sortField": {
            "type": "string",
            "default": "updatedAt",
            "enum": ["createdAt", "updatedAt"],
          },
          "sortDirection": {
            "type": "string",
            "default": "desc",
            "enum": ["asc", "desc"],
          },
          "limit": {
            "type": "integer",
            "default": 50,
            "minimum": 1,
            "maximum": 100,
          },
          "cursor": {
            "type": "string",
            "description": "An opaque cursor for pagination.",
          },
        },
      },
      "output": {
        "encoding": "application/json",
        "schema": {
          "type": "object",
          "required": ["subjects"],
          "properties": {
            "cursor": {"type": "string"},
            "subjects": {
              "type": "array",
              "items": {
                "type": "ref",
                "ref": "tools.ozone.inbox.defs#subjectView",
              },
            },
          },
        },
      },
    },
  },
};