toolsOzoneInboxUpdateSeen top-level constant

Map<String, dynamic> const toolsOzoneInboxUpdateSeen

tools.ozone.inbox.updateSeen

Implementation

const toolsOzoneInboxUpdateSeen = <String, dynamic>{
  "lexicon": 1,
  "id": "tools.ozone.inbox.updateSeen",
  "defs": {
    "main": {
      "type": "procedure",
      "input": {
        "encoding": "application/json",
        "schema": {
          "type": "object",
          "required": ["sections"],
          "properties": {
            "sections": {
              "type": "array",
              "items": {
                "type": "string",
                "knownValues": ["reports", "subjects", "accountStatus"],
              },
              "minLength": 1,
            },
            "seenAt": {
              "type": "string",
              "format": "datetime",
              "description":
                  "Mark each requested section read up to this instant. Defaults to server time and is clamped to server time when in the future. Newer existing watermarks are preserved independently for each section.",
            },
          },
        },
      },
      "output": {
        "encoding": "application/json",
        "schema": {
          "type": "object",
          "required": ["seenAt"],
          "properties": {
            "seenAt": {
              "type": "string",
              "format": "datetime",
              "description":
                  "The earliest resulting watermark across the requested sections, in UTC. Every requested section is read through this instant; individual sections may already have newer watermarks.",
            },
          },
        },
      },
    },
  },
};