toolsOzoneQueueAssignModerator top-level constant

Map<String, dynamic> const toolsOzoneQueueAssignModerator

tools.ozone.queue.assignModerator

Implementation

const toolsOzoneQueueAssignModerator = <String, dynamic>{
  "lexicon": 1,
  "id": "tools.ozone.queue.assignModerator",
  "defs": {
    "main": {
      "type": "procedure",
      "description": "Assign a user to a queue.",
      "input": {
        "encoding": "application/json",
        "schema": {
          "type": "object",
          "required": ["queueId", "did"],
          "properties": {
            "queueId": {
              "type": "integer",
              "description": "The ID of the queue to assign the user to.",
            },
            "did": {"type": "string", "description": "DID to be assigned."},
          },
        },
      },
      "output": {
        "encoding": "application/json",
        "schema": {
          "type": "ref",
          "ref": "tools.ozone.queue.defs#assignmentView",
        },
      },
      "errors": [
        {
          "name": "InvalidAssignment",
          "description":
              "The specified queue does not exist or is not enabled.",
        },
      ],
    },
  },
};