toolsOzoneQueueUnassignModerator top-level constant
tools.ozone.queue.unassignModerator
Implementation
const toolsOzoneQueueUnassignModerator = <String, dynamic>{
"lexicon": 1,
"id": "tools.ozone.queue.unassignModerator",
"defs": {
"main": {
"type": "procedure",
"description": "Remove a user's assignment from a queue.",
"input": {
"encoding": "application/json",
"schema": {
"type": "object",
"required": ["queueId", "did"],
"properties": {
"queueId": {
"type": "integer",
"description": "The ID of the queue to unassign the user from.",
},
"did": {
"type": "string",
"format": "did",
"description": "DID to be unassigned.",
},
},
},
},
"errors": [
{
"name": "InvalidAssignment",
"description":
"No active assignment exists for the given queue and user.",
},
],
},
},
};