LexXrpcSchema class sealed

Available extensions
Annotations
  • @freezed

Constructors

LexXrpcSchema.object({required LexObject data})
const
factory
LexXrpcSchema.refVariant({required LexRefVariant data})
const
factory

Properties

data Object
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult refVariant(ULexXrpcSchemaRefVariant value), required TResult object(ULexXrpcSchemaObject value)}) → TResult

Available on LexXrpcSchema, provided by the LexXrpcSchemaPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? refVariant(ULexXrpcSchemaRefVariant value)?, TResult? object(ULexXrpcSchemaObject value)?}) → TResult?

Available on LexXrpcSchema, provided by the LexXrpcSchemaPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult refVariant(ULexXrpcSchemaRefVariant value)?, TResult object(ULexXrpcSchemaObject value)?, required TResult orElse()}) → TResult

Available on LexXrpcSchema, provided by the LexXrpcSchemaPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult refVariant(LexRefVariant data)?, TResult object(LexObject data)?, required TResult orElse()}) → TResult

Available on LexXrpcSchema, provided by the LexXrpcSchemaPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult refVariant(LexRefVariant data), required TResult object(LexObject data)}) → TResult

Available on LexXrpcSchema, provided by the LexXrpcSchemaPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? refVariant(LexRefVariant data)?, TResult? object(LexObject data)?}) → TResult?

Available on LexXrpcSchema, provided by the LexXrpcSchemaPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited