LexXrpcSubscriptionMessage class abstract

Available extensions
Annotations
  • @freezed

Constructors

LexXrpcSubscriptionMessage({String? description, @LexXrpcSchemaConverter() LexXrpcSchema? schema})
const
factory
LexXrpcSubscriptionMessage.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $LexXrpcSubscriptionMessageCopyWith<LexXrpcSubscriptionMessage>
Create a copy of LexXrpcSubscriptionMessage with the given fields replaced by the non-null parameter values.
no setterinherited
description String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema LexXrpcSchema?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_LexXrpcSubscriptionMessage value)) → TResult

Available on LexXrpcSubscriptionMessage, provided by the LexXrpcSubscriptionMessagePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LexXrpcSubscriptionMessage value)?) → TResult?

Available on LexXrpcSubscriptionMessage, provided by the LexXrpcSubscriptionMessagePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LexXrpcSubscriptionMessage value)?, {required TResult orElse()}) → TResult

Available on LexXrpcSubscriptionMessage, provided by the LexXrpcSubscriptionMessagePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? description, LexXrpcSchema? schema)?, {required TResult orElse()}) → TResult

Available on LexXrpcSubscriptionMessage, provided by the LexXrpcSubscriptionMessagePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this LexXrpcSubscriptionMessage to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? description, LexXrpcSchema? schema)) → TResult

Available on LexXrpcSubscriptionMessage, provided by the LexXrpcSubscriptionMessagePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? description, LexXrpcSchema? schema)?) → TResult?

Available on LexXrpcSubscriptionMessage, provided by the LexXrpcSubscriptionMessagePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited